Class: SquashMatrixAPI::Game

Inherits:
Object
  • Object
show all
Defined in:
lib/squash_matrix_api/models/game.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Game

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/squash_matrix_api/models/game.rb', line 112

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v}

  if attributes.has_key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.has_key?(:'date')
    self.date = attributes[:'date']
  end

  if attributes.has_key?(:'division')
    self.division = attributes[:'division']
  end

  if attributes.has_key?(:'event')
    self.event = attributes[:'event']
  end

  if attributes.has_key?(:'round')
    self.round = attributes[:'round']
  end

  if attributes.has_key?(:'position')
    self.position = attributes[:'position']
  end

  if attributes.has_key?(:'player_a_name')
    self.player_a_name = attributes[:'player_a_name']
  end

  if attributes.has_key?(:'player_b_name')
    self.player_b_name = attributes[:'player_b_name']
  end

  if attributes.has_key?(:'player_a_id')
    self.player_a_id = attributes[:'player_a_id']
  end

  if attributes.has_key?(:'player_b_id')
    self.player_b_id = attributes[:'player_b_id']
  end

  if attributes.has_key?(:'player_a_points')
    self.player_a_points = attributes[:'player_a_points']
  end

  if attributes.has_key?(:'player_b_points')
    self.player_b_points = attributes[:'player_b_points']
  end

  if attributes.has_key?(:'player_a_games')
    self.player_a_games = attributes[:'player_a_games']
  end

  if attributes.has_key?(:'player_b_games')
    self.player_b_games = attributes[:'player_b_games']
  end

  if attributes.has_key?(:'player_a_rating')
    self.player_a_rating = attributes[:'player_a_rating']
  end

  if attributes.has_key?(:'player_b_rating')
    self.player_b_rating = attributes[:'player_b_rating']
  end

  if attributes.has_key?(:'player_a_rating_adjustment')
    self.player_a_rating_adjustment = attributes[:'player_a_rating_adjustment']
  end

  if attributes.has_key?(:'player_b_rating_adjustment')
    self.player_b_rating_adjustment = attributes[:'player_b_rating_adjustment']
  end

  if attributes.has_key?(:'match_id')
    self.match_id = attributes[:'match_id']
  end

end

Instance Attribute Details

#dateObject

Returns the value of attribute date.



20
21
22
# File 'lib/squash_matrix_api/models/game.rb', line 20

def date
  @date
end

#divisionObject

Returns the value of attribute division.



22
23
24
# File 'lib/squash_matrix_api/models/game.rb', line 22

def division
  @division
end

#eventObject

Returns the value of attribute event.



24
25
26
# File 'lib/squash_matrix_api/models/game.rb', line 24

def event
  @event
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/squash_matrix_api/models/game.rb', line 18

def id
  @id
end

#match_idObject

Squash Matrix mathch id



57
58
59
# File 'lib/squash_matrix_api/models/game.rb', line 57

def match_id
  @match_id
end

#player_a_gamesObject

Returns the value of attribute player_a_games.



44
45
46
# File 'lib/squash_matrix_api/models/game.rb', line 44

def player_a_games
  @player_a_games
end

#player_a_idObject

Player association



35
36
37
# File 'lib/squash_matrix_api/models/game.rb', line 35

def player_a_id
  @player_a_id
end

#player_a_nameObject

Returns the value of attribute player_a_name.



30
31
32
# File 'lib/squash_matrix_api/models/game.rb', line 30

def player_a_name
  @player_a_name
end

#player_a_pointsObject

Returns the value of attribute player_a_points.



40
41
42
# File 'lib/squash_matrix_api/models/game.rb', line 40

def player_a_points
  @player_a_points
end

#player_a_ratingObject

Returns the value of attribute player_a_rating.



48
49
50
# File 'lib/squash_matrix_api/models/game.rb', line 48

def player_a_rating
  @player_a_rating
end

#player_a_rating_adjustmentObject

Returns the value of attribute player_a_rating_adjustment.



52
53
54
# File 'lib/squash_matrix_api/models/game.rb', line 52

def player_a_rating_adjustment
  @player_a_rating_adjustment
end

#player_b_gamesObject

Returns the value of attribute player_b_games.



46
47
48
# File 'lib/squash_matrix_api/models/game.rb', line 46

def player_b_games
  @player_b_games
end

#player_b_idObject

Player association



38
39
40
# File 'lib/squash_matrix_api/models/game.rb', line 38

def player_b_id
  @player_b_id
end

#player_b_nameObject

Returns the value of attribute player_b_name.



32
33
34
# File 'lib/squash_matrix_api/models/game.rb', line 32

def player_b_name
  @player_b_name
end

#player_b_pointsObject

Returns the value of attribute player_b_points.



42
43
44
# File 'lib/squash_matrix_api/models/game.rb', line 42

def player_b_points
  @player_b_points
end

#player_b_ratingObject

Returns the value of attribute player_b_rating.



50
51
52
# File 'lib/squash_matrix_api/models/game.rb', line 50

def player_b_rating
  @player_b_rating
end

#player_b_rating_adjustmentObject

Returns the value of attribute player_b_rating_adjustment.



54
55
56
# File 'lib/squash_matrix_api/models/game.rb', line 54

def player_b_rating_adjustment
  @player_b_rating_adjustment
end

#positionObject

Returns the value of attribute position.



28
29
30
# File 'lib/squash_matrix_api/models/game.rb', line 28

def position
  @position
end

#roundObject

Returns the value of attribute round.



26
27
28
# File 'lib/squash_matrix_api/models/game.rb', line 26

def round
  @round
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/squash_matrix_api/models/game.rb', line 61

def self.attribute_map
  {
    :'id' => :'id',
    :'date' => :'date',
    :'division' => :'division',
    :'event' => :'event',
    :'round' => :'round',
    :'position' => :'position',
    :'player_a_name' => :'player_a_name',
    :'player_b_name' => :'player_b_name',
    :'player_a_id' => :'player_a_id',
    :'player_b_id' => :'player_b_id',
    :'player_a_points' => :'player_a_points',
    :'player_b_points' => :'player_b_points',
    :'player_a_games' => :'player_a_games',
    :'player_b_games' => :'player_b_games',
    :'player_a_rating' => :'player_a_rating',
    :'player_b_rating' => :'player_b_rating',
    :'player_a_rating_adjustment' => :'player_a_rating_adjustment',
    :'player_b_rating_adjustment' => :'player_b_rating_adjustment',
    :'match_id' => :'match_id'
  }
end

.swagger_typesObject

Attribute type mapping.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/squash_matrix_api/models/game.rb', line 86

def self.swagger_types
  {
    :'id' => :'Integer',
    :'date' => :'Date',
    :'division' => :'String',
    :'event' => :'String',
    :'round' => :'String',
    :'position' => :'String',
    :'player_a_name' => :'String',
    :'player_b_name' => :'String',
    :'player_a_id' => :'Integer',
    :'player_b_id' => :'Integer',
    :'player_a_points' => :'Integer',
    :'player_b_points' => :'Integer',
    :'player_a_games' => :'Integer',
    :'player_b_games' => :'Integer',
    :'player_a_rating' => :'Float',
    :'player_b_rating' => :'Float',
    :'player_a_rating_adjustment' => :'Float',
    :'player_b_rating_adjustment' => :'Float',
    :'match_id' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/squash_matrix_api/models/game.rb', line 211

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      date == o.date &&
      division == o.division &&
      event == o.event &&
      round == o.round &&
      position == o.position &&
      player_a_name == o.player_a_name &&
      player_b_name == o.player_b_name &&
      player_a_id == o.player_a_id &&
      player_b_id == o.player_b_id &&
      player_a_points == o.player_a_points &&
      player_b_points == o.player_b_points &&
      player_a_games == o.player_a_games &&
      player_b_games == o.player_b_games &&
      player_a_rating == o.player_a_rating &&
      player_b_rating == o.player_b_rating &&
      player_a_rating_adjustment == o.player_a_rating_adjustment &&
      player_b_rating_adjustment == o.player_b_rating_adjustment &&
      match_id == o.match_id
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
# File 'lib/squash_matrix_api/models/game.rb', line 271

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = SquashMatrixAPI.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/squash_matrix_api/models/game.rb', line 337

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/squash_matrix_api/models/game.rb', line 250

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


237
238
239
# File 'lib/squash_matrix_api/models/game.rb', line 237

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



243
244
245
# File 'lib/squash_matrix_api/models/game.rb', line 243

def hash
  [id, date, division, event, round, position, player_a_name, player_b_name, player_a_id, player_b_id, player_a_points, player_b_points, player_a_games, player_b_games, player_a_rating, player_b_rating, player_a_rating_adjustment, player_b_rating_adjustment, match_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



198
199
200
201
# File 'lib/squash_matrix_api/models/game.rb', line 198

def list_invalid_properties
  invalid_properties = Array.new
  return invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



317
318
319
# File 'lib/squash_matrix_api/models/game.rb', line 317

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



323
324
325
326
327
328
329
330
331
# File 'lib/squash_matrix_api/models/game.rb', line 323

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



311
312
313
# File 'lib/squash_matrix_api/models/game.rb', line 311

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



205
206
207
# File 'lib/squash_matrix_api/models/game.rb', line 205

def valid?
  return true
end